# Data for the stochastic pooling problem

#--------------------------------------
#----------	Set definitions	-----------
#--------------------------------------

Sources		= 1:4;		# number of sources
Pools 		= 1:1;		# number of pools
Terminals	= 1:2;		# number of terminals
Qualities	= 1:2;		# number of quality components
Scenarios	= 1:25;		# number of scenarios
Subh		= 1:5;		# number of scenarios per uncertain parameter
						# use size(Scenarios) = size(Subh)^2

#---------------------------------------
#----------	Network topology -----------
#---------------------------------------

T_SP = trues(size(Sources,1),size(Pools,1));

T_ST = falses(size(Sources,1),size(Terminals,1));
T_ST[3,1] = true;
T_ST[3,2] = true;
T_ST[4,1] = true;

T_PP = falses(size(Pools,1),size(Pools,1));

T_PT = trues(size(Pools,1),size(Terminals,1));

#------------------------------------------
#----------	Quality definitions	-----------
#------------------------------------------

Source_quality_nominal = zeros(size(Sources,1),size(Qualities,1));
Source_quality_nominal[1,1] = 3.0;
Source_quality_nominal[2,1] = 1.0;
Source_quality_nominal[3,1] = 2.0;
Source_quality_nominal[4,1] = 2.5;

for source in Sources
	sum_qualities = 0;
	for quality in Qualities
		sum_qualities += Source_quality_nominal[source,quality];
		if quality == size(Qualities,1)
			Source_quality_nominal[source,quality] = 100.0 - sum_qualities;
		end
		Source_quality_nominal[source,quality] /= 100.0;
	end
end

Source_quality_stdev = zeros(size(Sources,1),size(Qualities,1));
Source_quality_stdev[3,1] = 0.06/100.0;
Source_quality_stdev[4,1] = 0.08/100.0;

Terminal_quality_up = ones(size(Terminals,1),size(Qualities,1));
Terminal_quality_up[1,1] = 2.5/100.0;
Terminal_quality_up[2,1] = 1.5/100.0;

Terminal_quality_lo = zeros(size(Terminals,1),size(Qualities,1));

#------------------------------------------
#----------	Terminal demands	-----------
#------------------------------------------

Terminal_demand_up_nominal = [150.0, 200.0];
Terminal_demand_up_stdev = [0.0, 10.0];
Terminal_demand_lo = zeros(size(Terminals,1));

#------------------------------------------
#----------	Flow restrictions	-----------
#------------------------------------------

flow_S_up = 1000.0*ones(size(Sources,1));
flow_S_lo = zeros(size(Sources,1));

flow_SP_up = 350.0*ones(size(Sources,1),size(Pools,1));
flow_SP_lo = zeros(size(Sources,1),size(Pools,1));

flow_ST_up = 150.0*ones(size(Sources,1),size(Terminals,1));
flow_ST_up[3,2] = 200.0;
flow_ST_lo = zeros(size(Sources,1),size(Terminals,1));

flow_PP_up = 1000.0*ones(size(Pools,1),size(Pools,1));
flow_PP_lo = zeros(size(Pools,1),size(Pools,1));

flow_PT_up = 150.0*ones(size(Pools,1),size(Terminals,1));
flow_PT_up[1,2] = 200.0;
flow_PT_lo = zeros(size(Pools,1),size(Terminals,1));

#------------------------------
#----------	Costs	-----------
#------------------------------

Cost_source_flow = [6.0, 15.0, 9.0, 8.0];
Price_terminal_flow = [9.0, 15.0];
Investment_cost_S = [120.0, 300.0, 135.0, 110.0];
Investment_cost_P = 10.0*ones(size(Pools,1));
Investment_cost_T = 10.0*ones(size(Terminals,1));
Investment_cost_SP = 10.0*ones(size(Sources,1),size(Pools,1));
Investment_cost_ST = 10.0*ones(size(Sources,1),size(Terminals,1));
Investment_cost_PP = 10.0*ones(size(Pools,1),size(Pools,1));
Investment_cost_PT = 10.0*ones(size(Pools,1),size(Terminals,1));

#----------------------------------------------------------
#--------------	Define the uncertain parameters	-----------
#----------------------------------------------------------

sub_probability = zeros(size(Subh,1));
probability = zeros(size(Scenarios,1));

Source_quality = zeros(size(Sources,1),size(Qualities,1),size(Scenarios,1));
Terminal_demand_up = zeros(size(Terminals,1),size(Scenarios,1));

for scenario in Scenarios
	for source in Sources
		for quality in Qualities
			Source_quality[source,quality,scenario] = Source_quality_nominal[source,quality];
		end
	end
end

for scenario in Scenarios
	for terminal in Terminals
		Terminal_demand_up[terminal,scenario] = Terminal_demand_up_nominal[terminal];
	end
end

if size(Scenarios,1) == 1
	probability[1] = 1.0;
else
	if size(Scenarios,1) != (size(Subh,1))^2
		print("ERROR! size(Subh)^2 != size(Scenarios) \n");
	else
		for sub in Subh
			if sub == 1
				sub_probability[sub] = (1 + erf((-3.0 + 6.0/size(Subh,1))/sqrt(2)))/2.0;
			elseif sub == size(Subh,1)
				sub_probability[sub] = 1 - (1 + erf((-3.0 + (size(Subh,1) - 1)*6.0/size(Subh,1))/sqrt(2)))/2.0;
			else
				sub_probability[sub] = (1 + erf((-3.0 + sub*6.0/size(Subh,1))/sqrt(2)))/2.0 - 
										(1 + erf((-3.0 + (sub-1)*6.0/size(Subh,1))/sqrt(2)))/2.0;
			end
		end

		for sub in Subh
			for sub2 in Subh
				scenario = sub + (sub2-1)*size(Subh,1);
				probability[scenario] = sub_probability[sub]*sub_probability[sub2];

				Source_quality[3,1,scenario] = Source_quality_nominal[3,1] - 
												3.0*Source_quality_stdev[3,1]*(1.0 - 1.0/size(Subh,1)) +
												(sub-1)*6.0*Source_quality_stdev[3,1]/size(Subh,1);
				Source_quality[3,2,scenario] = 1.0 - Source_quality[3,1,scenario];

				Source_quality[4,1,scenario] = Source_quality_nominal[4,1] - 
												3.0*Source_quality_stdev[4,1]*(1.0 - 1.0/size(Subh,1)) +
												(sub2-1)*6.0*Source_quality_stdev[4,1]/size(Subh,1);
				Source_quality[4,2,scenario] = 1.0 - Source_quality[4,1,scenario];
			end
		end
	end
end

#=
print(Source_quality);
print("\n");
print(Terminal_demand_up);
print("\n");
print(probability);
print("\n");
=#
